@@ -23,7 +23,9 @@ def get_deploy_params(connection_string, id_project):
     conn = psycopg.connect(connection_string, row_factory=dict_row)
 
     cursor = conn.cursor()
-    cursor.execute('SELECT server, project_path, deploy_user FROM projects WHERE project_id=%s', [id_project])
+    cursor.execute('''select project_path, a.server,deploy_user from projects a 
+                    inner join servers b on a.server=b.server
+                   WHERE project_id=%s''', [id_project])
     row = cursor.fetchone()
     conn.close()
 
